
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "gallery/auto_examples/nddataset/plot_units.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        :ref:`Go to the end <sphx_glr_download_gallery_auto_examples_nddataset_plot_units.py>`
        to download the full example code

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_gallery_auto_examples_nddataset_plot_units.py:


Units manipulation examples
===========================

In this example, we show how units can be used in SpectroChemPy

.. GENERATED FROM PYTHON SOURCE LINES 17-20

.. code-block:: default


    import spectrochempy as scp








.. GENERATED FROM PYTHON SOURCE LINES 21-23

Spectrochempy can do calculations with units - it uses [pint](https://pint.readthedocs.io) to define and perform
operation on data with units.

.. GENERATED FROM PYTHON SOURCE LINES 25-28

Create quantities
-----------------
To create quantity, use for instance, one of the following expression:

.. GENERATED FROM PYTHON SOURCE LINES 28-34

.. code-block:: default


    scp.Quantity("10.0 cm^-1")

    ""
    scp.Quantity(1.0, "cm^-1/hour")






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    1.0 cm<sup>-1</sup>.h<sup>-1</sup>
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 35-36

or may be simpler using `ur`:

.. GENERATED FROM PYTHON SOURCE LINES 36-40

.. code-block:: default


    ur = scp.ur
    10.0 * ur.meter / ur.gram / ur.volt






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    10.0 m.V<sup>-1</sup>.g<sup>-1</sup>
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 41-42

`ur` stands for **unit registry**, which handle many type of units (and conversion between them)

.. GENERATED FROM PYTHON SOURCE LINES 44-48

Units for dataset
-----------------

When loading experimental dataset using the `read` method, units are generally attributed to coordinates and data

.. GENERATED FROM PYTHON SOURCE LINES 48-54

.. code-block:: default


    ds = scp.read("wodger.spg")[0]
    prefs = ds.preferences
    prefs.figure.figsize = (7, 3)
    _ = ds.plot()




.. image-sg:: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_001.png
   :alt: plot units
   :srcset: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_001.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 55-57

* `wavenumbers` (`x` ) coordinates are here expressed in $cm^{-1}$
* and `data` are in absorbance ($a.u.$) units.

.. GENERATED FROM PYTHON SOURCE LINES 59-63

Convert between units
----------------------

Here are some examples

.. GENERATED FROM PYTHON SOURCE LINES 63-67

.. code-block:: default


    x = 36 * ur("km/hr")
    x.to("cm/s")






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    1000.0 cm.s<sup>-1</sup>
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 68-69

We can make the conversion *inplace* using *ito* instead of *to*

.. GENERATED FROM PYTHON SOURCE LINES 69-73

.. code-block:: default


    x.ito("m/s")
    x






.. raw:: html

    <div class="output_subarea output_html rendered_html output_result">
    10.0 m.s<sup>-1</sup>
    </div>
    <br />
    <br />

.. GENERATED FROM PYTHON SOURCE LINES 74-75

Obviously you cannot convert between incompatible units

.. GENERATED FROM PYTHON SOURCE LINES 75-81

.. code-block:: default


    try:
        x.to("hour")
    except scp.DimensionalityError as e:
        scp.error_(scp.DimensionalityError, e)








.. GENERATED FROM PYTHON SOURCE LINES 82-84

This, of course, also applies to NDDataset.
Let's try for the `x` coordinate. It is `wavenumber` in $cm^{-1}$ that can be transformed in $Hz$ for instance:

.. GENERATED FROM PYTHON SOURCE LINES 84-88

.. code-block:: default


    ds.x.ito("terahertz")
    _ = ds.plot()




.. image-sg:: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_002.png
   :alt: plot units
   :srcset: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_002.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 89-91

We can also change the wavenumbers (or frequency units), to energy units or wavelength as
Spectrochempy (thanks to [pint](https://pint.readthedocs.io)) knows how to make the transformation.

.. GENERATED FROM PYTHON SOURCE LINES 91-106

.. code-block:: default


    ds.x.ito("eV")
    _ = ds.plot()

    ""
    try:
        ds.x.ito("nanometer")
    except Exception as e:
        scp.error_(Exception, e)

    ""
    ds.x = ds.x.to("nanometer")
    print(ds.x)
    _ = ds.plot()




.. rst-class:: sphx-glr-horizontal


    *

      .. image-sg:: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_003.png
         :alt: plot units
         :srcset: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_003.png
         :class: sphx-glr-multi-img

    *

      .. image-sg:: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_004.png
         :alt: plot units
         :srcset: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_004.png
         :class: sphx-glr-multi-img


.. rst-class:: sphx-glr-script-out

 .. code-block:: none

    Coord: [float64] nm (size: 5549)




.. GENERATED FROM PYTHON SOURCE LINES 107-108

`absorbance` units (the units of the data) can also be transformed into `transmittance`

.. GENERATED FROM PYTHON SOURCE LINES 108-117

.. code-block:: default


    ds.ito("transmittance")
    _ = ds.plot()

    ""
    ds.ito("absorbance")
    ds.x.ito("cm^-1")
    _ = ds.plot()




.. rst-class:: sphx-glr-horizontal


    *

      .. image-sg:: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_005.png
         :alt: plot units
         :srcset: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_005.png
         :class: sphx-glr-multi-img

    *

      .. image-sg:: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_006.png
         :alt: plot units
         :srcset: /gallery/auto_examples/nddataset/images/sphx_glr_plot_units_006.png
         :class: sphx-glr-multi-img





.. GENERATED FROM PYTHON SOURCE LINES 118-120

This ends the example ! The following line can be uncommented if no plot shows when running
the .py script

.. GENERATED FROM PYTHON SOURCE LINES 122-123

scp.show()


.. rst-class:: sphx-glr-timing

   **Total running time of the script:** ( 0 minutes  1.052 seconds)


.. _sphx_glr_download_gallery_auto_examples_nddataset_plot_units.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example




    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: plot_units.py <plot_units.py>`

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: plot_units.ipynb <plot_units.ipynb>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
